@@ -14,13 +14,25 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
-package Dpkg::Source::Package::V1;
+=encoding utf8
+
+=head1 NAME
+
+Dpkg::Source::Package::V1 - class for source format 1.0
+
+=head1 DESCRIPTION
+
+This module provides a class to handle the source package format 1.0.
+
+B<Note>: This is a private module, its API can change at any time.
+
+=cut
+
+package Dpkg::Source::Package::V1 0.01;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
-
 use Errno qw(ENOENT);
 use Cwd;
 use File::Basename;
@@ -36,7 +48,6 @@ use Dpkg::Source::Patch;
 use Dpkg::Exit qw(push_exit_handler pop_exit_handler);
 use Dpkg::Source::Functions qw(erasedir);
 use Dpkg::Source::Package::V3::Native;
-use Dpkg::OpenPGP;
 
 use parent qw(Dpkg::Source::Package);
 
@@ -63,10 +74,14 @@ sub init_options {
     $self->{options}{ignore_bad_version} //= 0;
     $self->{options}{abort_on_upstream_changes} //= 0;
 
+    # Set default validation checks.
+    $self->{options}{require_valid_signature} //= 0;
+    $self->{options}{require_strong_checksums} //= 0;
+
     # V1.0 only supports gzip compression.
     $self->{options}{compression} //= 'gzip';
-    $self->{options}{comp_level} //= compression_get_property('gzip', 'default_level');
-    $self->{options}{comp_ext} //= compression_get_property('gzip', 'file_ext');
+    $self->{options}{comp_level} //= compression_get_level('gzip');
+    $self->{options}{comp_ext} //= compression_get_file_extension('gzip');
 }
 
 my @module_cmdline = (
@@ -162,8 +177,6 @@ sub do_extract {
 	         $sourcestyle);
     }
 
-    my $dscdir = $self->{basedir};
-
     my $basename = $self->get_basename();
     my $basenamerev = $self->get_basename(1);
 
@@ -209,7 +222,9 @@ sub do_extract {
         }
 
         info(g_('unpacking %s'), $tarfile);
-        my $tar = Dpkg::Source::Archive->new(filename => "$dscdir$tarfile");
+        my $tar = Dpkg::Source::Archive->new(
+            filename => File::Spec->catfile($self->{basedir}, $tarfile),
+        );
         $tar->extract($expectprefix);
 
         if ($sourcestyle =~ /u/) {
@@ -234,7 +249,7 @@ sub do_extract {
     }
 
     if ($difffile and not $self->{options}{skip_debianization}) {
-        my $patch = "$dscdir$difffile";
+        my $patch = File::Spec->catfile($self->{basedir}, $difffile);
 	info(g_('applying %s'), $difffile);
 	my $patch_obj = Dpkg::Source::Patch->new(filename => $patch);
 	my $analysis = $patch_obj->apply($newdirectory, force_timestamp => 1);
@@ -352,7 +367,7 @@ sub do_build {
         error(g_('non-native package version does not contain a revision'))
             if $v->is_native();
     } else {
-        # FIXME: This will become fatal in the near future.
+        # TODO: This will become fatal in the near future.
         warning(g_('native package version may not have a revision'))
             unless $v->is_native();
     }
@@ -422,14 +437,14 @@ sub do_build {
     if ($tarname) {
         $self->add_file($tarname);
         if (-e "$tarname.sig" and not -e "$tarname.asc") {
-            openpgp_sig_to_asc("$tarname.sig", "$tarname.asc");
+            $self->armor_original_tarball_signature("$tarname.sig", "$tarname.asc");
         }
     }
     if ($tarsign and -e $tarsign) {
+        $self->check_original_tarball_signature($dir, $tarsign);
+
         info(g_('building %s using existing %s'), $sourcepackage, $tarsign);
         $self->add_file($tarsign);
-
-        $self->check_original_tarball_signature($dir, $tarsign);
     } else {
         my $key = $self->get_upstream_signing_key($dir);
         if (-e $key) {
@@ -444,9 +459,7 @@ sub do_build {
                          'giving up; use -sA, -sK or -sP to override'),
                       $origdir);
             }
-            push_exit_handler(sub { erasedir($origdir) });
             erasedir($origdir);
-            pop_exit_handler();
         } elsif ($! != ENOENT) {
             syserr(g_("unable to check for existence of orig directory '%s'"),
                     $origdir);
@@ -508,4 +521,12 @@ sub do_build {
     }
 }
 
+=head1 CHANGES
+
+=head2 Version 0.xx
+
+This is a private module.
+
+=cut
+
 1;
